@@ -189,6 +189,7 @@ func readSecrets(r io.Reader) ([]*v1.Secret, error) {
 			return nil, err
 		}
 	}
+
 	return secrets, nil
 }
 
@@ -226,6 +227,10 @@ func Seal(clientConfig ClientConfig, outputFormat string, in io.Reader, out io.W
 		return err
 	}
 
+	if len(secrets) == 0 {
+		return fmt.Errorf("no secrets found. Ensure the input is valid and UTF-8 encoded")
+	}
+
 	for _, secret := range secrets {
 		if len(secret.Data) == 0 && len(secret.StringData) == 0 && !allowEmptyData {
 			return fmt.Errorf("secret.data is empty in input Secret, assuming this is an error and aborting. To work with empty data, --allow-empty-data can be used")
